﻿using Hotline.Orders;
using Hotline.Quality;
using MapsterMapper;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.Repository.SqlSugar.DataPermissions;
using SqlSugar;
using XF.Domain.Authentications;
using XF.Domain.Dependency;
using Hotline.Share.Dtos.Quality;
using Hotline.Share.Enums.Quality;
using Hotline.Share.Dtos.Order;

namespace Hotline.Repository.SqlSugar.Orders
{
	public class CitizenRepository : BaseRepository<Citizen>, ICitizenRepository, IScopeDependency
	{
		private readonly ISessionContext _sessionContext;
		private readonly IMapper _mapper;
		private readonly IOrderRepository _orderRepository;

		public CitizenRepository(
			ISugarUnitOfWork<HotlineDbContext> uow,
			IDataPermissionFilterBuilder dataPermissionFilterBuilder,
			ISessionContext sessionContext,
			IOrderRepository orderRepository,
			IMapper mapper
		) : base(uow, dataPermissionFilterBuilder)
		{
			_sessionContext = sessionContext;
			_orderRepository = orderRepository;
			_mapper = mapper;
		}

		public async Task AddAsync(CitizenAddDto citizen, CancellationToken cancellationToken)
		{
			var firstCallTime = await _orderRepository.Queryable().Where(x => x.FromPhone == citizen.PhoneNumber).MinAsync(x => x.CreationTime);
			firstCallTime = firstCallTime == null ? DateTime.Now : firstCallTime;
			citizen.FirstCallTime = firstCallTime;
			var addCitizen = _mapper.Map<Citizen>(citizen);
			await AddAsync(addCitizen, cancellationToken);
		}
	}
}
